// ************************************************************
//							     L C D - R O U T I N E S
//         for Electronic Assembly's DOGM LCD series
//                      -- Header-File --
// ************************************************************
//
// 	Author:			Mario Richter
// 	File:	      dogm.h
// 	Project:		Routines for DOGM LCD series
// 	Date:			  March 2009
// 	Target MCU:	not specified
//
// DESCRIPTION
//
// 	Routines for the DOGMxxx LCD series by Electonic Assembly
//  with ST7036 controller.
//
// ************************************************************

#ifndef __DOGM__
#define __DOGM__

#include <util/delay.h>

// Port Definitions -- change to suit your application
// ------------------------------------------------------------

#define DOGM_D4_PORT      PORTC
#define DOGM_D4_PIN       (1<<PC0)

#define DOGM_D5_PORT      PORTC
#define DOGM_D5_PIN       (1<<PC1)

#define DOGM_D6_PORT      PORTC
#define DOGM_D6_PIN       (1<<PC2)

#define DOGM_D7_PORT      PORTC
#define DOGM_D7_PIN       (1<<PC3)

#define DOGM_E_PORT       PORTC
#define DOGM_E_PIN        (1<<PC4)

#define DOGM_RW_PORT      PORTC
#define DOGM_RW_PIN       (1<<PC5)

#define DOGM_RS_PORT      PORTC
#define DOGM_RS_PIN       (1<<PC6)


// DDR(x) and PIN(x) macros - taken from Peter Fleury's LCD routines
// ------------------------------------------------------------

#define DDR(x) (*(&x - 1))      /* address of data direction register of port x */
#if defined(__AVR_ATmega64__) || defined(__AVR_ATmega128__)
    /* on ATmega64/128 PINF is on port 0x00 and not 0x60 */
    #define PIN(x) ( &PORTF==&(x) ? _SFR_IO8(0x00) : (*(&x - 2)) )
#else
	#define PIN(x) (*(&x - 2))    /* address of input register of port x          */
#endif


// Function Declarations
// ------------------------------------------------------------

void dogm_init(void);                         // Initialize LCD
void dogm_putc(char);                         // Write character to display
void dogm_puts(char *);                       // Write string to display
void dogm_gotoxy(uint8_t, uint8_t);           // Go to position
void dogm_clear(void);                        // Clear display, go to first char in first line

// Internal routines
void dogm_port_init(void);                    // Initialize ports for LCD module
void dogm_write_check(uint8_t, uint8_t);      // Do busy check and write 8 bit to LCD
void dogm_write_nocheck(uint8_t, uint8_t);    // Write 8 bit to LCD without busy check
void dogm_write_once(uint8_t);                // Write 4 bit to LCD without busy check
void dogm_chk_busy(void);                     // Busy Check

#endif
